@@ -1,5 +1,5 @@
 """
-This file is part of GFS (python component).
+This file is part of gfs_sampler.
 
 GFS is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -15,10 +15,10 @@ You should have received a copy of the GNU General Public License
 along with GFS. If not, see <https://www.gnu.org/licenses/>.
 """
 
-from GFS.master import *
-from GFS.distributions import *
-from GFS.helpers import *
+from gfs_sampler.master import *
+from gfs_sampler.distributions import *
+from gfs_sampler.helpers import *
 
-from GFS import *
+from gfs_sampler import *
 
 __all__ = ["distributions", "helpers"]
